@@ -20,7 +20,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, 
  * Boston, MA  02110-1301, USA.
  * 
- * see the COPYING file included in the csv2latex package or
+ * see the LICENSE file included in the csv2latex package or
  * http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt
  * 
  */
@@ -645,10 +645,11 @@ int main (int argc, char **argv) {
 
 	if (optind == argc) {
 		/* copy stdin into tmp file */
-		int c;
+		char buf[BUFSIZ];
+
 		fp = tmpfile();
-		while (EOF != (c = getc(stdin))) {
-			putc(c, fp);
+		while (fgets(buf, BUFSIZ, stdin)) {
+			fputs(buf, fp);
 		}
 		rewind(fp);
 	} else {
